@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.language_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -57,7 +69,7 @@ class LanguageServiceClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[LanguageServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -257,7 +269,7 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -312,8 +324,8 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, LanguageServiceTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, LanguageServiceTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the language service client.
@@ -327,7 +339,7 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
             transport (Union[str, LanguageServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -357,6 +369,7 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -409,12 +422,12 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
 
     def analyze_sentiment(
         self,
-        request: Union[language_service.AnalyzeSentimentRequest, dict] = None,
+        request: Optional[Union[language_service.AnalyzeSentimentRequest, dict]] = None,
         *,
-        document: language_service.Document = None,
-        encoding_type: language_service.EncodingType = None,
+        document: Optional[language_service.Document] = None,
+        encoding_type: Optional[language_service.EncodingType] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> language_service.AnalyzeSentimentResponse:
         r"""Analyzes the sentiment of the provided text.
@@ -516,12 +529,12 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
 
     def analyze_entities(
         self,
-        request: Union[language_service.AnalyzeEntitiesRequest, dict] = None,
+        request: Optional[Union[language_service.AnalyzeEntitiesRequest, dict]] = None,
         *,
-        document: language_service.Document = None,
-        encoding_type: language_service.EncodingType = None,
+        document: Optional[language_service.Document] = None,
+        encoding_type: Optional[language_service.EncodingType] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> language_service.AnalyzeEntitiesResponse:
         r"""Finds named entities (currently proper names and
@@ -623,12 +636,14 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
 
     def analyze_entity_sentiment(
         self,
-        request: Union[language_service.AnalyzeEntitySentimentRequest, dict] = None,
+        request: Optional[
+            Union[language_service.AnalyzeEntitySentimentRequest, dict]
+        ] = None,
         *,
-        document: language_service.Document = None,
-        encoding_type: language_service.EncodingType = None,
+        document: Optional[language_service.Document] = None,
+        encoding_type: Optional[language_service.EncodingType] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> language_service.AnalyzeEntitySentimentResponse:
         r"""Finds entities, similar to
@@ -733,12 +748,12 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
 
     def analyze_syntax(
         self,
-        request: Union[language_service.AnalyzeSyntaxRequest, dict] = None,
+        request: Optional[Union[language_service.AnalyzeSyntaxRequest, dict]] = None,
         *,
-        document: language_service.Document = None,
-        encoding_type: language_service.EncodingType = None,
+        document: Optional[language_service.Document] = None,
+        encoding_type: Optional[language_service.EncodingType] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> language_service.AnalyzeSyntaxResponse:
         r"""Analyzes the syntax of the text and provides sentence
@@ -839,11 +854,11 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
 
     def classify_text(
         self,
-        request: Union[language_service.ClassifyTextRequest, dict] = None,
+        request: Optional[Union[language_service.ClassifyTextRequest, dict]] = None,
         *,
-        document: language_service.Document = None,
+        document: Optional[language_service.Document] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> language_service.ClassifyTextResponse:
         r"""Classifies a document into categories.
@@ -936,13 +951,13 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
 
     def annotate_text(
         self,
-        request: Union[language_service.AnnotateTextRequest, dict] = None,
+        request: Optional[Union[language_service.AnnotateTextRequest, dict]] = None,
         *,
-        document: language_service.Document = None,
-        features: language_service.AnnotateTextRequest.Features = None,
-        encoding_type: language_service.EncodingType = None,
+        document: Optional[language_service.Document] = None,
+        features: Optional[language_service.AnnotateTextRequest.Features] = None,
+        encoding_type: Optional[language_service.EncodingType] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> language_service.AnnotateTextResponse:
         r"""A convenience method that provides all the features
@@ -1066,14 +1081,9 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-language",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("LanguageServiceClient",)
